# Pyndoc

A standalone Pandoc filter and optional preprocessor to include arbitrary Python code in Markdown documents, ran at build time.

**Note:** Please note that this package is in active development, and as such may not be stable. Additionally, the documentation is incomplete and may be partially out of date.

---

Check out the [documentation](docs/docs.md) for more information on how to use Pyndoc.